/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.talk.model

import android.os.Parcelable
import com.google.gson.annotations.SerializedName
import com.kakao.sdk.common.json.UnknownValue
import kotlinx.android.parcel.Parcelize

/**
 * 카카오톡 채팅방 목록 조회 API 응답 모델.
 *
 * @property totalCount 전체 채팅방 수
 * @property elements 채팅방 목록
 */
@Parcelize
data class Chats(val totalCount: Int, val elements: List<Chat>) : Parcelable

/**
 * 카카오톡 채팅방 정보.
 *
 * @property id 채팅방 아이디
 * @property title 채팅방 이름
 * @property imageUrl 이미지 URL
 * @property memberCount 참여한 멤버 수
 * @property displayMemberImages
 * @property chatType
 */
@Parcelize
data class Chat(
    val id: Long,
    val title: String,
    val imageUrl: String?,
    val memberCount: Int,
    val displayMemberImages: List<String>,
    val chatType: Type
) : Parcelable {

    /**
     * 채팅방의 종류
     */
    enum class Type {
        /**
         * 일반채팅
         */
        @SerializedName("regular")
        REGULAR,
        /**
         * 오픈채팅
         */
        @SerializedName("open")
        OPEN,
        @UnknownValue
        UNKNOWN;
    }
}

/**
 * 채팅방 목록 필터링 옵션
 */
enum class ChatFilter(val value: String) {
    /**
     *  1:1 채팅방만 필터링하여 결과에 포함시킨다
     */
    @SerializedName("direct")
    DIRECT("direct"),
    /**
     * 그룹 채팅방만 필터링하여 결과에 포함시킨다.
     */
    @SerializedName("multi")
    MULTI("multi"),
    /**
     * 일반 채팅방만 필터링하여 결과에 포함시킨다.
     */
    @SerializedName("regular")
    REGULAR("regular"),
    /**
     * 오픈 채팅방만 필터링하여 결과에 포함시킨다.
     */
    @SerializedName("open")
    OPEN("open");
}